%
% Flash PBeta:
% 
% Ref: Henley e Seader 
%      pag 274

clear all
close all
clc
warning off

%Valores especificados:

F=100;   % vazao de alimentacao (kgmole/hr)
Pfextensao=300:1:450;  % Pressao (psia)
fiextensao=0.1:0.01:0.99;   %fi
[Pfvetor,fivetor]=meshgrid(Pfextensao,fiextensao); %cria a malha
z1=0.10;  % composicao da alimentacao
z2=0.20;  % composicao da alimentacao
z3=0.30;  % composicao da alimentacao

Tv=350;  % temperatura da saida vapor  (Farenheit)
Pv=450;  % pressao da saida vapor (psia)


% 1)
Tl=Tv;

% 2)
Pl=Pv;

% 3)
z4=1-z1-z2-z3;


% Inicializando as variaveis:
[Ax,Ay]=size(fivetor);
Vvetor=zeros(Ax,Ay);
Fvetor=zeros(Ax,Ay);
Lvetor=zeros(Ax,Ay);
Qvetor=zeros(Ax,Ay);
Xvetor1=zeros(Ax,Ay);
Yvetor1=zeros(Ax,Ay);
Tfvetor=zeros(Ax,Ay);
i=1;


% Loop:
while (i<=Ax*Ay),
    
	Pf=Pfvetor(i);
	fi=fivetor(i);
   
    
    % 5)
        % Sabendo fi, chuto Tf ate convergir:
        % (resolvendo por fzero)
		pars=[z1 z2 z3 z4 fi Pf];
		Tf = fzero('fnc4',200,[],pars);
	    Tfvetor(i)=Tf; 
        
        
	% 6)
		V= F* fi;

        
	% 7)
        % 7.1)
    		% Assumindo valores de k(t,p):
		
			% Pela Equacao de Antoine (eq 4-69, pag 159):
			% (valores de Pc do apendice 1, parte A, pag 715)
			% (valores de A1, A2, A3 do apendice 1, parte B, pag 720)
            % (temperatura em Farenheit)
            % (pressao em psia)
			A1=5.383894   ; A2=2847.921    ; A3=434.898    ; Pc=709.8  ; T=Tf;  %Substancia 48
			divisao=exp( A1 - ( A2/(T+A3)  )  );
			Ps1=Pc*divisao;
			
			A1=5.353418   ; A2=3371.084    ; A3=414.488    ; Pc=617.4  ; T=Tf;  %Substancia 64
			divisao=exp( A1 - ( A2/(T+A3)  )  );
			Ps2=Pc*divisao;
			
			A1= 5.741624   ; A2=4126.385    ; A3=409.5179   ; Pc=550.7  ; T=Tf;   %Substancia 87
			divisao=exp( A1 - ( A2/(T+A3)  )  );
			Ps3=Pc*divisao;
			
			A1=5.853654   ; A2=4598.287    ; A3=394.4148    ; Pc=489.5  ; T=Tf;    %Substancia 104
			divisao=exp( A1 - ( A2/(T+A3)  )  );
			Ps4=Pc*divisao;
   
    
		% 7.2)
        	% Pela Lei de Raoult (eq 4-75, pag 161):
			P=Pf;
			k1=Ps1/P;
			k2=Ps2/P;
			k3=Ps3/P;
			k4=Ps4/P;

         % 7.3)
			x1= z1/(1+(fi*(k1-1)));
			x2= z2/(1+(fi*(k2-1)));
			x3= z3/(1+(fi*(k3-1)));
			x4= z4/(1+(fi*(k4-1)));
			X=[x1 x2 x3 x4];
			Xvetor1(i)=x1;
	
	% 8)
		y1=(z1*k1)/(1+(fi*(k1-1)));
		y2=(z2*k2)/(1+(fi*(k2-1)));
		y3=(z3*k3)/(1+(fi*(k3-1)));
		y4=(z4*k4)/(1+(fi*(k4-1)));
		Y=[y1 y2 y3 y4];
		Yvetor1(i)=y1;
	
	% 9)
		L=F-V;
        
        Fvetor(i)=F;
        Vvetor(i)=V;
        Lvetor(i)=L;
    
	% 10)
		%Corrente de vapor:
        par=[Pv,Tv,y1,y2,y3,y4]; %Pv em psia e Tv em Fahrenheit
        [Hv]=hvfcn(par);
        
        %Corrente de liquido:
        par=[Pl,Tl,x1,x2,x3,x4]; %Pl em psia e Tl em Fahrenheit
        [Hl]=hlfcn(par);   
	
        %Corrente de entrada:
        par=[Pf,Tf,z1,z2,z3,z4]; %Pf em psia e Tf em Fahrenheit
        [Hf]=hlfcn(par);
	
        %Q:
        Q=(Hv*V)+(Hl*L)-(Hf*F);
        Qvetor(i)=Q;
    
    % Incrementa o contador:
    i=i+1;



end

figure(1);
surf(fivetor,Pfvetor,Xvetor1);
shading interp;
xlabel('Fi');
ylabel('Pf')
zlabel('Fracao do 1 componente (X)');


figure(3);
surf(fivetor,Pfvetor,Lvetor);
shading interp;
xlabel('Fi');
ylabel('Pf')
zlabel('L')

figure(4);
surf(fivetor,Pfvetor,Vvetor);
shading interp;
xlabel('Fi');
ylabel('Pf')
zlabel('V')


figure(5);
surf(fivetor,Pfvetor,Qvetor);
shading interp;
xlabel('Fi');
ylabel('Pf')
zlabel('Q')

figure(6);
 surf(fivetor,Tfvetor,Pfvetor);
 shading interp;
xlabel('Fi')
ylabel('Tf')
zlabel('Pf')

