%
% Flash TBeta:
% 
% Ref: Henley e Seader 
%      pag 274

clear all
close all
clc
warning off

%Valores especificados:


Tfvetor=230:1:300;  % temperatura (Farenheit)
fi=0.6;   %fi
z1=0.10;  % composicao da alimentacao
z2=0.20;  % composicao da alimentacao
z3=0.30;  % composicao da alimentacao

F=100;   % vazao de alimentacao (kgmole/hr)


% 1)
z4=1-z1-z2-z3;


% Inicializando as variaveis:
Vvetor=[];
Fvetor=[];
Lvetor=[];
Qvetor=[];
Xvetor=[];
Yvetor=[];
Pfvetor=[];
i=1;


% Loop para cada temperatura:
while (i<=length(Tfvetor)),
    
   Tf=Tfvetor(i);
       
       
	% 4) 
		% Assumindo valores de k(t,p):
		
		% Pela Equacao de Antoine (eq 4-69, pag 159):
		% (valores de Pc do apendice 1, parte A, pag 715)
		% (valores de A1, A2, A3 do apendice 1, parte B, pag 720)
        % (temperatura em Farenheit)
        % (pressao em psia)
		A1=5.383894   ; A2=2847.921    ; A3=434.898    ; Pc=709.8  ; T=Tf;  %Substancia 48
		divisao=exp( A1 - ( A2/(T+A3)  )  );
		Ps1=Pc*divisao;
		
		A1=5.353418   ; A2=3371.084    ; A3=414.488    ; Pc=617.4  ; T=Tf;  %Substancia 64
		divisao=exp( A1 - ( A2/(T+A3)  )  );
		Ps2=Pc*divisao;
		
		A1= 5.741624   ; A2=4126.385    ; A3=409.5179   ; Pc=550.7  ; T=Tf;   %Substancia 87
		divisao=exp( A1 - ( A2/(T+A3)  )  );
		Ps3=Pc*divisao;
		
		A1=5.853654   ; A2=4598.287    ; A3=394.4148    ; Pc=489.5  ; T=Tf;    %Substancia 104
		divisao=exp( A1 - ( A2/(T+A3)  )  );
		Ps4=Pc*divisao;
	
    
    % 5)
        % Sabendo fi, chuto Pf ate convergir:
        % (resolvendo por fzero)
		pars=[z1 z2 z3 z4 fi Ps1 Ps2 Ps3 Ps4];
		Pf = fzero('fnc3',400,[],pars);
	    Pfvetor=[Pfvetor;Pf]; 
        
        
	% 6)
		V= F* fi;

        
	% 7)
		% 7.1)
        	% Pela Lei de Raoult (eq 4-75, pag 161):
			P=Pf;
			k1=Ps1/P;
			k2=Ps2/P;
			k3=Ps3/P;
			k4=Ps4/P;

         % 7.2)
			x1= z1/(1+(fi*(k1-1)));
			x2= z2/(1+(fi*(k2-1)));
			x3= z3/(1+(fi*(k3-1)));
			x4= z4/(1+(fi*(k4-1)));
			X=[x1 x2 x3 x4];
			Xvetor=[Xvetor;X];
	
	% 8)
		y1=(z1*k1)/(1+(fi*(k1-1)));
		y2=(z2*k2)/(1+(fi*(k2-1)));
		y3=(z3*k3)/(1+(fi*(k3-1)));
		y4=(z4*k4)/(1+(fi*(k4-1)));
		Y=[y1 y2 y3 y4];
		Yvetor=[Yvetor;Y];
	
	% 9)
		L=F-V;
        
        Fvetor=[Fvetor; F];
        Vvetor=[Vvetor; V];
        Lvetor=[Lvetor; L];
    
   
    % Incrementa o contador:
    i=i+1;



end

figure(1);
plot(Tfvetor,Xvetor);
xlabel('Temperatura');
ylabel('X')
legend('1 componente','2 componente','3 componente','4 componente');

figure(2);
plot(Tfvetor,Yvetor);
xlabel('Temperatura');
ylabel('Y')
legend('1 componente','2 componente','3 componente','4 componente');

figure(3);
plot(Tfvetor,Lvetor,'-b')
xlabel('Temperatura');
hold on
plot(Tfvetor,Vvetor','-r')
legend('Liquido','Vapor')
xlabel('Temperatura');
ylabel('Vazao')
axis([230 300 0 100])

figure(4);
plot(Tfvetor,Pfvetor);
xlabel('Temperatura');
ylabel('Pressao')
