function [Hl] = hlfcn(par)
%------------------------------------------------------------
% Calculo de HL real (baseado na eq 4.65 - pag 156)
%------------------------------------------------------------

P=par(1);
T=par(2); % em Fahrenheit
Trank=T+95; % em Rankine;
x1=par(3);
x2=par(4);
x3=par(5);
x4=par(6);




% Calculo de Hv0 pela eq 4.60 pag154
% (valores de a1,a2,a3 e a4 da tabela do Apendice)

	% Substancia 1 (48):
		a1=11.51606;     
		a2=0.140309e-1;
		a3=0.854034e-5;
		a4=-0.1106078e-7;
		a5=0.3162199e-11;
		T0=0; %temperatura padrao na tabela (Fahrenheit)
		H1v0= ( (a1*((T^1) - (T0^1)) )/1 ) + ( (a2*((T^2) - (T0^2)) )/2 )  + (  (a3*((T^3) - (T0^3)) )/3  )  +  ( (a4*((T^4) - (T0^4)) )/4  )  +  ( (a5*((T^5) - (T0^5)) )/5 );
		
	
	% Substancia 2 (64):
		a1=15.58683;     
		a2=0.2504953e-1;
		a3=0.1404258e-4;
		a4=-0.3526261e-7;
		a5=0.1864467e-10;
		T0=0; %temperatura padrao na tabela (Fahrenheit)
		H2v0= ( (a1*((T^1) - (T0^1)) )/1 ) + ( (a2*((T^2) - (T0^2)) )/2 )  + (  (a3*((T^3) - (T0^3)) )/3  )  +  ( (a4*((T^4) - (T0^4)) )/4  )  +  ( (a5*((T^5) - (T0^5)) )/5 );
		
	
	% Substancia 3 (87) :
		a1=20.79783;     
		a2=0.3143287e-1;
		a3=0.1928511e-4;
		a4=-0.4588652e-7;
		a5=0.2380972e-10;
		T0=0; %temperatura padrao na tabela (Fahrenheit)
		H3v0= ( (a1*((T^1) - (T0^1)) )/1 ) + ( (a2*((T^2) - (T0^2)) )/2 )  + (  (a3*((T^3) - (T0^3)) )/3  )  +  ( (a4*((T^4) - (T0^4)) )/4  )  +  ( (a5*((T^5) - (T0^5)) )/5 );
		
	
	% Substancia 4  (104):
		a1=25.64627;     
		a2=0.389176e-1;
		a3=0.2397294e-4;
		a4=-0.5842615e-7;
		a5=0.3079918e-10;
		T0=0; %temperatura padrao na tabela (Fahrenheit)
		H4v0= ( (a1*((T^1) - (T0^1)) )/1 ) + ( (a2*((T^2) - (T0^2)) )/2 )  + (  (a3*((T^3) - (T0^3)) )/3  )  +  ( (a4*((T^4) - (T0^4)) )/4  )  +  ( (a5*((T^5) - (T0^5)) )/5 );

        
        

% Constante:
		
		R=1.987;  % >>>>>>>>>>>>>>>>>>>>>>>>>>>CONFIRMAR ESSE VALOR EM FUNCAO DAS UNIDADES   (rankine  e psia) 





%Calculo de A e B :
% (valores de Pc e Tc da tabela do Apendice I)

	   	
	  % Substancia 1 (48):
        Pc= 709.8    ;  % em psia (tabela apendice I)
        Tc= 550.0    ;  % em Rankine (tabela apendice I)
        Tr=Trank/Tc;  % temperatura reduzida  
        A1=(0.4278/(Pc*(Tr^2.5)))^0.5; % (eq 4.44 e 4.45 pag 152)
        B1=0.0867/(Pc*Tr);
        
        
   	  % Substancia 2  (64):
        Pc= 617.4    ;  % em psia (tabela apendice I)
        Tc= 665.9   ;  % em Rankine (tabela apendice I)
        Tr=Trank/Tc;  % temperatura reduzida      
	    A2=(0.4278/(Pc*(Tr^2.5)))^0.5; % (eq 4.44 e 4.45 pag 152)
        B2=0.0867/(Pc*Tr);
        
        
      % Substancia 3 (87) :
        Pc= 550.7   ;  % em psia (tabela apendice I)
        Tc= 765.3   ;  % em Rankine (tabela apendice I)
        Tr=Trank/Tc;  % temperatura reduzida       
		A3=(0.4278/(Pc*(Tr^2.5)))^0.5; % (eq 4.44 e 4.45 pag 152)
        B3=0.0867/(Pc*Tr);
        
        
      % Substancia 4  (104):
        Pc= 489.5   ;  % em psia (tabela apendice I)
        Tc= 845.6   ;  % em Rankine (tabela apendice I)
        Tr=Trank/Tc;  % temperatura reduzida  
        A4=(0.4278/(Pc*(Tr^2.5)))^0.5; % (eq 4.44 e 4.45 pag 152)
        B4=0.0867/(Pc*Tr);
        
     

	  % Mistura:
		A = (A1*x1) + (A2*x2)  + (A3*x3) + (A4*x4); % (equacoes 4.42 4.43 - pag 152):
		B = (B1*x1) + (B2*x2)  + (B3*x3) + (B4*x4);


        


%Calculo de Zv (eq 4.41 pag 151):
		coef1=1;
		coef2=-1;
		coef3=B*P*( ((A^2)/B)  - (B*P) - 1 );
		coef4=-1*((A^2)/B)*((B*P)^2);
		raizes=roots([coef1 coef2 coef3 coef4]);
                
       %Guarda apenas as raizes reais:
        for ii = 1:length(raizes),
            if (~isreal(raizes(ii))),   % eh real? 0 false, 1 true
               raizes(ii)=nan;
            end
       end
          
		Zl=min(raizes); % a menor raiz real eh Zv  (pag 152)




% Calculo de Hv (eq 4.64 pag 156):
        Hl= (x1*H1v0 + x2*H2v0 + x3*H2v0 + x4*H2v0) + ...
                (  R * Trank * ( Zl - 1 - (  ((3*A^2)* log(1+((B*P)/Zl)) )/(2*B) )      )   );  
            
